%global _version 2.0.7
%global _release 3
Name:      clibcni
Version:   %{_version}
Release:   %{_release}
Summary:   CNI - the Container Network Interface
Group:     System Environment/Libraries
License:   Mulan PSL v2
URL:       https://gitee.com/openeuler/clibcni
Source0:   https://gitee.com/openeuler/clibcni/repository/archive/v%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}

%define lcrver_lower 2.0.8-0
%define lcrver_upper 2.0.9-0

BuildRequires: gcc git gcc-c++
BuildRequires: cmake
BuildRequires: lcr-devel > %{lcrver_lower} yajl-devel gtest-devel gmock-devel

Requires:      lcr > %{lcrver_lower}

%ifarch x86_64 aarch64
Provides:       lib%{name}.so()(64bit)
%endif

%description
CNI (Container Network Interface), a Cloud Native Computing Foundation project,
consists of a specification and libraries for writing plugins to configure
network interfaces in Linux containers, along with a number of supported
plugins. CNI concerns itself only with network connectivity of containers and
removing allocated resources when the container is deleted. Because of this
focus, CNI has a wide range of support and the specification is simple to implement.

%package devel
Summary: Huawei CNI C Library
Group:   Libraries
ExclusiveArch:  x86_64 aarch64
Requires:       %{name} = %{version}-%{release}

%description devel
the %{name}-libs package contains libraries for running %{name} applications.

%prep
%autosetup -n clibcni-v%{_version} -Sgit -p1

%build
mkdir -p build
cd build
%cmake -DDEBUG=ON -DCMAKE_SKIP_RPATH=TRUE -DLIB_INSTALL_DIR=%{_libdir} ../
%make_build

%install
rm -rf %{buildroot}
cd build
install -d $RPM_BUILD_ROOT/%{_libdir}
install -m 0644 ./src/libclibcni.so        %{buildroot}/%{_libdir}/libclibcni.so
chmod +x %{buildroot}/%{_libdir}/libclibcni.so

install -d $RPM_BUILD_ROOT/%{_libdir}/pkgconfig
install -m 0644 ./conf/clibcni.pc      %{buildroot}/%{_libdir}/pkgconfig/clibcni.pc

install -d $RPM_BUILD_ROOT/%{_includedir}/clibcni
install -m 0644 ../src/api.h           %{buildroot}/%{_includedir}/clibcni/api.h
install -m 0644 ../src/types/types.h   %{buildroot}/%{_includedir}/clibcni/types.h
install -m 0644 ../src/version/version.h %{buildroot}/%{_includedir}/clibcni/version.h


find %{buildroot} -type f -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'
find %{buildroot} -name '*.cmake' -exec rm -f {} ';'

%clean
rm -rf %{buildroot}

%pre

%post   -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_libdir}/lib%{name}.so*

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}/*.h
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Oct 18 2022 zhangxiaoyu <zhangxiaoyu58@huawei.com> - 2.0.7-3
- Type: enhancement
- ID: NA
- SUG: NA
- DESC: add required package lcr lower and upper version

* Thu Jun 2 2022 haozi007 <liuhao27@huawei.com> - 2.0.7-2
- Type: enhancement
- ID: NA
- SUG: NA
- DESC: remove rpath by cmake

* Thu Feb 24 2022 wangfengtu <wangfengtu@huawei.com> - 2.0.7-1
- Type: enhancement
- ID: NA
- SUG: NA
- DESC: update to version v2.0.7

* Mon Jan 10 2022 haozi007 <liuhao27@huawei.com> - 2.0.6-7
- Type: sync patch from upstream
- ID: NA
- SUG: NA
- DESC: sync from openeuler

* Mon Jan 10 2022 haozi007 <liuhao27@huawei.com> - 2.0.6-6
- Type: adapt to new gmock
- ID: NA
- SUG: NA
- DESC: add gmock build requires

* Mon Dec 06 2021 gaohuatao <gaohuatao@huawei.com> - 2.0.6-5
- Type: enhancement
- ID: NA
- SUG: NA
- DESC: specify version

* Tue Nov 23 2021 liuhao <liuhao27@huawei.com> - 2.0.6-4
- Type: enhancement
- ID: NA
- SUG: NA
- DESC: improve coverage of ut

* Mon Nov 22 2021 liuhao <liuhao27@huawei.com> - 2.0.6-3
- Type: enhancement
- ID: NA
- SUG: NA
- DESC: improve coverage of ut

* Tue Nov 16 2021 wujing <wujing50@huawei.com> - 2.0.6-2
- Type: enhancement
- ID: NA
- SUG: NA
- DESC: remove build platform restrictions

* Tue Nov 09 2021 haozi007 <liuhao27@huawei.com> - 2.0.6-1
- Type: upgrade version
- ID: NA
- SUG: NA
- DESC: upgrade to v2.0.6

* Mon Jun 28 2021 haozi007 <liuhao27@huawei.com> - 2.0.4-20210628.190359.git14c104bc
- Type: add g++ to build require
- ID: NA
- SUG: NA
- DESC: add g++ to build require

* Mon Jun 28 2021 haozi007 <liuhao27@huawei.com> - 2.0.4-20210628.151504.git61ae9f6b
- Type: add git to build require
- ID: NA
- SUG: NA
- DESC: add git to build require

* Sat May 8 2021 zhangxiaoyu <zhangxiaoyu58@huawei.com> - 2.0.4-20210508.150021.git73679d5d
- Type: sync from upstream
- ID: NA
- SUG: NA
- DESC: update from master

* Wed Dec 30 2020 lifeng <lifeng68@huawei.com> - 2.0.4-20201230.152647.gitf9277cd7
- Type: update version to v2.0.4
- ID:NA
- SUG:NA

* Sat Nov 28 2020 haozi007 <liuhao27@huawei.com> - 2.0.3-20201128.142102.git866f22d3
- Type:bugfix
- ID:NA
- SUG:NA
- DESC: fix parse ipv6 format error

* Thu Nov 12 2020 gaohuatao <gaohuatao@huawei.com> - 2.0.3-20201112.165252.gitc4aadda4
- Type:enhancement
- ID:NA
- SUG:NA
- DESC: update from openeuler master

* Fri Sep 04 2020 zhangxiaoyu <zhangxiaoyu58@huawei.com> - 2.0.3-20200904.104745.git413e6757
- Type:enhancement
- ID:NA
- SUG:NA
- DESC: upgrade from v2.0.2 to v2.0.3
